@@ -60,10 +60,21 @@ class Atmosphere(pd.DataFrame):
         Number of discretization steps.
     h_step : float
         Size of discretization step in km.
+    Xv_total : float
+        Total vertical depth of the atmosphere.
     model : int
         CORSIKA atmospheric model. Presently either 1 or 17. More models to
         be implemented.
 
+    Methods
+    -------
+    h_to_Xv()
+        Get vertical depth from height.
+    h_to_rho()
+        Get mass density from height.
+    Xv_to_h()
+        Get height from vertical depth.
+
     See also
     --------
     Track : DataFrame containing a shower track discretization.
@@ -87,7 +98,6 @@ class Atmosphere(pd.DataFrame):
         Returns
         -------
         Xv : float or array_like
-            Vertical depth in g/cm^2.
         """
         Xv, rho = self._get_Xv_rho(h)
         return Xv
@@ -104,7 +114,6 @@ class Atmosphere(pd.DataFrame):
         Returns
         -------
         rho : float or array_like
-            Mass density in g/cm^3.
         """
         Xv, rho = self._get_Xv_rho(h)
         return rho
@@ -122,22 +131,29 @@ class Atmosphere(pd.DataFrame):
 
         Parameters
         ----------
-        Xv : float or array_like
+        Xv : float
             Vertical depth in g/cm^2.
 
         Returns
         -------
-        h : float or array_like
-            Height in km.
+        h : float
         """
-        if Xv == 0:
+        if Xv==0:
             return self.h_top
+        elif Xv<0.:
+            return None
+        elif Xv>self.Xv_total:
+            return None
 
-        h_lower = self.h[self.X_vert > Xv].max()  # Lower bound for h
-        h_upper = self.h[self.X_vert < Xv].min()  # Lower bound for h
+        h = np.append(self.h0, self.h)
+        h = np.append(h, self.h_top)
+        X_vert = np.append(self.Xv_total, self.X_vert)
+        X_vert = np.append(X_vert, 0.)
+        h_lower = h[X_vert > Xv].max()  # Lower bound for h
+        h_upper = h[X_vert < Xv].min()  # Lower bound for h
         # Upper and lower bounds for Xv (corresponding to h_lower and  h_upper)
-        Xv_upper = self.X_vert[self.X_vert > Xv].min()
-        Xv_lower = self.X_vert[self.X_vert < Xv].max()
+        Xv_upper = X_vert[X_vert > Xv].min()
+        Xv_lower = X_vert[X_vert < Xv].max()
         # An exponential atmosphere is assumed to interpolate h
         # The approximation is good enough for the top atmosphere too
         # (more or less linear)
@@ -187,8 +203,10 @@ def _atmosphere(atmosphere, h0, h_top, N_steps, model):
     atmosphere.h = height[1:] - atmosphere.h_step/2.
 
     # Vertical depth and density from the input model
-    Xv, rho = atmosphere._get_Xv_rho(atmosphere.h)
+    Xv, rho = atmosphere._get_Xv_rho(h0)
+    atmosphere.Xv_total = Xv
 
+    Xv, rho = atmosphere._get_Xv_rho(atmosphere.h)
     atmosphere.X_vert = Xv
     atmosphere.rho = rho
 
