@@ -35,6 +35,11 @@ class Fluorescence(pd.DataFrame):
         Column 33, number of fluorescence photons in the band centered at 428 nm.
     profile : Profile
     atmosphere : Atmosphere
+
+    Methods
+    -------
+    show()
+        Show the production of fluorescence photons as a function of slant depth.
     """
     # Parameters of the fluorescence model (34 bands)
     #     wvl(nm),   Irel,   PP0,  PPw,     a
@@ -78,7 +83,7 @@ class Fluorescence(pd.DataFrame):
     # Y0_337=7.05 ph/MeV is the fluorescence yield of the band at 337nm in
     # dry air at reference conditions
     # J. Rosado et al. Astropart. Phys. 55(2014)51.
-    Y0_337 = 7.05
+    Y0_337 = 7.04
     
     def __init__(self, profile):
         columns = [wvl[0] for wvl in self.model]
@@ -121,6 +126,11 @@ def _fluorescence(fluorescence, profile):
     
     P0 = fluorescence.P0
     T0 = fluorescence.T0
+    
+    atm = profile.atmosphere.iloc[profile.index]
+    P = atm.P
+    temp = atm.temp
+    P_w = atm.P_w
 
     # Number of emitted photons at wavelength wvl as a function of pressure P,
     # temperature T and partial pressure P_w of water vapor:
@@ -129,12 +139,9 @@ def _fluorescence(fluorescence, profile):
         # water vapor is available
         if PPw == 0:
             fluorescence[wvl] = (
-                N0_337 * I_rel * (1. + P0 / PP0)
-                / (1. + profile.atmosphere.P / PP0
-                   * (T0 / profile.atmosphere.temp)**(0.5 - a)))
+                N0_337 * I_rel * (1. + P0 / PP0) / (1. + P / PP0
+                   * (T0 / temp)**(0.5 - a)))
         else:
             fluorescence[wvl] = (
-                N0_337 * I_rel * (1. + P0 / PP0)
-                / (1. + ((profile.atmosphere.P - profile.atmosphere.P_w) / PP0
-                         + profile.atmosphere.P_w / PPw)
-                   * (T0 / profile.atmosphere.temp)**(0.5 - a)))
\ No newline at end of file
+                N0_337 * I_rel * (1. + P0 / PP0) / (1. + ((P - P_w) / PP0
+                   + P_w / PPw) * (T0 / temp)**(0.5 - a)))
\ No newline at end of file
